==> cantata_2.4.1.ds1.orig.tar.xz: cantata-2.4.1/README.md <==
Cantata
=======

**NOTE** Cantata is now in a bug-fix only state. Therefore, new features are unlikly to be implemented unless pull requests are submitted. The current release, 2.4.0, is likely to be the last feature release.

![ScreenShot](screenshots/mainwindow.png)


A graphical (Qt5) client for MPD, supporting the following features:

  1. Supports Linux, macOS, Windows, and Haiku. **NOTE:** Only Linux actively supported as of 2.3.3
  2. Multiple MPD collections.
  3. Highly customisable layout.
  4. Songs (optionally) grouped by album in play queue.
  5. Context view to show artist, album, and song information of current track.
  6. Simple tag editor.
  7. File organizer - use tags to organize files and folders.
  8. Ability to calculate ReplyGain tags. (Linux only, and if relevant libraries installed)
  9. Dynamic playlists.
 10. Smart Playlists.
 11. Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
 12. Radio stream support - with the ability to search for streams via TuneIn, ShoutCast, or Dirble.
 13. USB-Mass-Storage and MTP device support. (Linux only, and if relevant libraries installed)
 14. Audio CD ripping and playback. (Linux only, and if relevant libraries installed)
 15. Playback of non-MPD songs - via simple in-built HTTP server.
 16. MPRISv2 DBUS interface.
 17. Scrobbling.
 18. Ratings support.

Cantata started off as a fork of QtMPC, however, the code (and user interface) is now *very* different to that of QtMPC.
For more detailed information, please refer to the main [README](https://raw.githubusercontent.com/CDrummond/cantata/master/README)


---

[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/craigd)

## Donations

I develop Cantata purely for fun, so no donations are required. However, seeing as I have been asked about this a few times, here is a link...

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=2X2CTDUH27V9L&source=url)

==> cantata_2.4.2.ds1.orig.tar.xz: cantata-2.4.2/README.md <==
Cantata
=======

**NOTE** Cantata is now in a bug-fix only state. Therefore, new features are unlikly to be implemented unless pull requests are submitted. The current release, 2.4.x, is likely to be the last feature release.

![ScreenShot](screenshots/mainwindow.png)


A graphical (Qt5) client for MPD, supporting the following features:

  1. Supports Linux, macOS, Windows, and Haiku. **NOTE:** Only Linux actively supported as of 2.3.3
  2. Multiple MPD collections.
  3. Highly customisable layout.
  4. Songs (optionally) grouped by album in play queue.
  5. Context view to show artist, album, and song information of current track.
  6. Simple tag editor.
  7. File organizer - use tags to organize files and folders.
  8. Ability to calculate ReplyGain tags. (Linux only, and if relevant libraries installed)
  9. Dynamic playlists.
 10. Smart Playlists.
 11. Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
 12. Radio stream support - with the ability to search for streams via TuneIn, ShoutCast, or Dirble.
 13. USB-Mass-Storage and MTP device support. (Linux only, and if relevant libraries installed)
 14. Audio CD ripping and playback. (Linux only, and if relevant libraries installed)
 15. Playback of non-MPD songs - via simple in-built HTTP server.
 16. MPRISv2 DBUS interface.
 17. Scrobbling.
 18. Ratings support.

Cantata started off as a fork of QtMPC, however, the code (and user interface) is now *very* different to that of QtMPC.
For more detailed information, please refer to the main [README](https://raw.githubusercontent.com/CDrummond/cantata/master/README)


---

[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/craigd)

## Donations

I develop Cantata purely for fun, so no donations are required. However, seeing as I have been asked about this a few times, here is a link...

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=2X2CTDUH27V9L&source=url)
